==> revision_graph-3.0.0.tar.gz: revision_graph/revision-graph-js/src/index.ts <==
import { RevisionGraphGenerator } from "./RevisionGraphGenerator";
import { RevisionListGenerator } from "./RevisionListGenerator";
import type { Commit, GraphOptions as BaseGraphOptions } from "./types";
import "./styles.css";

/**
 * Extended GraphOptions interface with additional callback
 */
interface GraphOptions extends BaseGraphOptions {
    /** Callback when a commit is selected */
    onCommitSelect?: (commit: Commit) => void;
}

/**
 * RevisionGraph class for creating visual representations of revision history
 */
export class RevisionGraph {
    private readonly options: GraphOptions;
    private graphGenerator: RevisionGraphGenerator | null = null;
    private listGenerator: RevisionListGenerator | null = null;

    /**
     * Creates a new instance of RevisionGraph
     * @param options - Configuration options for the graph
     */
    constructor(options: Partial<GraphOptions> = {}) {
        // Set default options
        this.options = {
            width: 800,
            nodeHeight: 40,
            nodeWidth: 20,
            columnWidth: 50,
            colors: ["#222222"],
            showLabels: true,
            theme: "light",
            branchColors: new Map(),
            ...options
        };
    }

    /**
     * Renders the revision graph
     * @param container - The container element to render the graph in
     * @param commits - Array of commits to render
     * @returns The graph generator instance
     */
    renderGraph(container: HTMLElement, commits: Commit[]): RevisionGraphGenerator {
        // Create container if it doesn't exist
        if (!container.classList.contains("revision-graph")) {
            const graphContainer = document.createElement("div");
            graphContainer.className = "revision-graph";
            container.appendChild(graphContainer);
            container = graphContainer;
        }

        // Set theme if provided
        if (this.options.theme === "dark") {
            container.setAttribute("data-theme", "dark");
        }

        // Create graph generator
        this.graphGenerator = new RevisionGraphGenerator(container, this.options);

        // Generate graph
        this.graphGenerator.generate(commits);

        return this.graphGenerator;
    }

    /**
     * Renders the revision list
     * @param container - The container element to render the list in
     * @param commits - Array of commits to render
     * @returns The list generator instance
     */
    renderList(container: HTMLElement, commits: Commit[]): RevisionListGenerator {
        // Create container if it doesn't exist
        if (!container.classList.contains("revision-graph")) {
            const listContainer = document.createElement("div");
            listContainer.className = "revision-graph";
            container.appendChild(listContainer);
            container = listContainer;
        }

        // Set theme if provided
        if (this.options.theme === "dark") {
            container.setAttribute("data-theme", "dark");
        }

        // Create list generator
        this.listGenerator = new RevisionListGenerator(container, {
            ...this.options,
            onCommitSelect: (commitId: string) => {
                // Find the commit by ID
                const commit = commits.find(c => c.id === commitId);
                if (!commit) return;

                // Trigger onCommitSelect callback if provided
                if (this.options.onCommitSelect) {
                    this.options.onCommitSelect(commit);
                }
            }
        });

        // Render list
        this.listGenerator.render(commits);

        return this.listGenerator;
    }

    /**
     * Renders both the graph and list side by side
     * @param container - The container element to render in
     * @param commits - Array of commits to render
     * @returns Object containing both generator instances
     */
    renderFull(container: HTMLElement, commits: Commit[]): { graph: RevisionGraphGenerator, list: RevisionListGenerator } {
        // Create main container
        const mainContainer = document.createElement("div");
        mainContainer.className = "revision-graph";
        mainContainer.style.display = "flex";
        mainContainer.style.flexDirection = "row";
        mainContainer.style.width = "100%";
        mainContainer.style.height = "100%";

        // Set theme if provided
        if (this.options.theme === "dark") {
            mainContainer.setAttribute("data-theme", "dark");
        }

        // Create graph container
        const graphContainer = document.createElement("div");
        graphContainer.className = "revision-graph__container";
        graphContainer.style.flex = "1";
        graphContainer.style.minWidth = "0";
        mainContainer.appendChild(graphContainer);

        // Create list container
        const listContainer = document.createElement("div");
        listContainer.className = "revision-graph__list-container";
        listContainer.style.width = "350px";
        listContainer.style.overflow = "auto";
        mainContainer.appendChild(listContainer);

        // Add to main container
        container.appendChild(mainContainer);

        // Render graph and list
        const graph = this.renderGraph(graphContainer, commits);
        const list = this.renderList(listContainer, commits);

        return { graph, list };
    }

    /**
     * Cleans up resources
     */
    cleanup(): void {
        if (this.graphGenerator) {
            this.graphGenerator.cleanup();
            this.graphGenerator = null;
        }

        if (this.listGenerator) {
            this.listGenerator.cleanup();
            this.listGenerator = null;
        }
    }
}

export * from "./RevisionGraphGenerator";
export * from "./RevisionListGenerator";
export * from "./types";

// For IIFE builds, we need to expose the RevisionGraph class globally
declare global {
  interface Window {
    RevisionGraph: typeof RevisionGraph;
  }
}

// This will be replaced by Vite's build process
if (typeof window !== "undefined") {
  window.RevisionGraph = RevisionGraph;
}

==> revision_graph-3.1.1.tar.gz: revision_graph/revision-graph-js/src/index.ts <==
import { RevisionGraphGenerator } from "./RevisionGraphGenerator";
import { RevisionListGenerator } from "./RevisionListGenerator";
import type { Commit, GraphOptions as BaseGraphOptions, UITextOptions } from "./types";
import "./styles.css";

/**
 * Extended GraphOptions interface with additional callback
 */
interface GraphOptions extends BaseGraphOptions {
    /** Callback when a commit is selected */
    onCommitSelect?: (commit: Commit) => void;
}

/**
 * Default UI text options
 */
const DEFAULT_UI_TEXT: UITextOptions = {
    revisionTerm: "Revision",
    historyTerm: "Revision history",
    graphVisualizationLabel: "Revision graph visualization",
    interactiveGraphLabel: "Interactive revision graph",
    graphDescription: "Visual representation of content revision history showing branches and connections between revisions",
    detailsLabel: "Revision details",
    closeButtonLabel: "Close revision details",
    actionsLabel: "Revision actions",
    historyListLabel: "Revision history"
};

/**
 * RevisionGraph class for creating visual representations of Git commit history
 */
export class RevisionGraph {
    private readonly options: GraphOptions;
    private readonly uiText: UITextOptions;
    private graphGenerator: RevisionGraphGenerator | null = null;
    private listGenerator: RevisionListGenerator | null = null;

    /**
     * Creates a new instance of RevisionGraph
     * @param options - Configuration options for the graph
     */
    constructor(options: Partial<GraphOptions> = {}) {
        // Set default options
        this.options = {
            width: 800,
            nodeHeight: 40,
            nodeWidth: 20,
            columnWidth: 50,
            colors: ["#222222"],
            showLabels: true,
            theme: "light",
            branchColors: new Map(),
            ...options
        };

        // Set UI text with defaults that can be overridden
        this.uiText = { ...DEFAULT_UI_TEXT, ...options.uiText };
    }

    /**
     * Renders the revision graph
     * @param container - The container element to render the graph in
     * @param commits - Array of commits to render
     * @returns The graph generator instance
     */
    renderGraph(container: HTMLElement, commits: Commit[]): RevisionGraphGenerator {
        // Create container if it doesn't exist
        if (!container.classList.contains("revision-graph")) {
            const graphContainer = document.createElement("div");
            graphContainer.className = "revision-graph";
            container.appendChild(graphContainer);
            container = graphContainer;
        }

        // Set theme if provided
        if (this.options.theme === "dark") {
            container.setAttribute("data-theme", "dark");
        }

        // Create graph generator with UI text options
        const graphOptions = {
            ...this.options,
            uiText: this.uiText
        };
        
        this.graphGenerator = new RevisionGraphGenerator(container, graphOptions);

        // Generate graph
        this.graphGenerator.generate(commits);

        return this.graphGenerator;
    }

    /**
     * Renders the revision list
     * @param container - The container element to render the list in
     * @param commits - Array of commits to render
     * @returns The list generator instance
     */
    renderList(container: HTMLElement, commits: Commit[]): RevisionListGenerator {
        // Create container if it doesn't exist
        if (!container.classList.contains("revision-graph")) {
            const listContainer = document.createElement("div");
            listContainer.className = "revision-graph";
            container.appendChild(listContainer);
            container = listContainer;
        }

        // Set theme if provided
        if (this.options.theme === "dark") {
            container.setAttribute("data-theme", "dark");
        }

        // Create list generator with UI text options
        this.listGenerator = new RevisionListGenerator(container, {
            theme: this.options.theme,
            colors: this.options.colors,
            branchColors: this.options.branchColors,
            uiText: this.uiText,
            onCommitSelect: (revisionId: string) => {
                // Find the commit by ID
                const commit = commits.find(c => c.id === revisionId);
                if (!commit) return;

                // Trigger onCommitSelect callback if provided
                if (this.options.onCommitSelect) {
                    this.options.onCommitSelect(commit);
                }
            }
        });

        // Render list
        this.listGenerator.render(commits);

        return this.listGenerator;
    }

    /**
     * Renders both the graph and list side by side
     * @param container - The container element to render in
     * @param commits - Array of commits to render
     * @returns Object containing both generator instances
     */
    renderFull(container: HTMLElement, commits: Commit[]): { graph: RevisionGraphGenerator, list: RevisionListGenerator } {
        // Create main container
        const mainContainer = document.createElement("div");
        mainContainer.className = "revision-graph";
        mainContainer.style.display = "flex";
        mainContainer.style.flexDirection = "row";
        mainContainer.style.width = "100%";
        mainContainer.style.height = "100%";

        // Set theme if provided
        if (this.options.theme === "dark") {
            mainContainer.setAttribute("data-theme", "dark");
        }

        // Create graph container
        const graphContainer = document.createElement("div");
        graphContainer.className = "revision-graph__container";
        graphContainer.style.flex = "1";
        graphContainer.style.minWidth = "0";
        mainContainer.appendChild(graphContainer);

        // Create list container
        const listContainer = document.createElement("div");
        listContainer.className = "revision-graph__list-container";
        listContainer.style.width = "350px";
        listContainer.style.overflow = "auto";
        mainContainer.appendChild(listContainer);

        // Add to main container
        container.appendChild(mainContainer);

        // Render graph and list
        const graph = this.renderGraph(graphContainer, commits);
        const list = this.renderList(listContainer, commits);

        return { graph, list };
    }

    /**
     * Cleans up resources
     */
    cleanup(): void {
        if (this.graphGenerator) {
            this.graphGenerator.cleanup();
            this.graphGenerator = null;
        }

        if (this.listGenerator) {
            this.listGenerator.cleanup();
            this.listGenerator = null;
        }
    }
}

export * from "./RevisionGraphGenerator";
export * from "./RevisionListGenerator";
export * from "./types";

// For IIFE builds, we need to expose the RevisionGraph class globally
declare global {
  interface Window {
    RevisionGraph: typeof RevisionGraph;
  }
}

// This will be replaced by Vite's build process
if (typeof window !== "undefined") {
  window.RevisionGraph = RevisionGraph;
}
